@@ -1,13 +1,12 @@
 # pylint: disable=no-self-argument,no-name-in-module
 import re
-
 from typing import Dict, List, Optional
-from pydantic import BaseModel, AnyHttpUrl, Field, validator, root_validator
+
+from pydantic import AnyHttpUrl, BaseModel, Field, root_validator, validator
 
 from optimade.models.jsonapi import Resource
 from optimade.models.utils import SemanticVersion, StrictField
 
-
 __all__ = ("AvailableApiVersion", "BaseInfoAttributes", "BaseInfoResource")
 
 
