@@ -1,14 +1,13 @@
 # pylint: disable=no-self-argument
 from enum import Enum
+from typing import Dict, Union
 
-from pydantic import Field, BaseModel  # pylint: disable=no-name-in-module
-from typing import Union, Dict
+from pydantic import BaseModel, Field  # pylint: disable=no-name-in-module
 
-from optimade.models.jsonapi import BaseResource
 from optimade.models.baseinfo import BaseInfoAttributes, BaseInfoResource
+from optimade.models.jsonapi import BaseResource
 from optimade.models.utils import StrictField
 
-
 __all__ = (
     "IndexInfoAttributes",
     "RelatedLinksResource",
@@ -54,7 +53,7 @@ class IndexInfoResource(BaseInfoResource):
     attributes: IndexInfoAttributes = Field(...)
     relationships: Union[
         None, Dict[DefaultRelationship, IndexRelationship]
-    ] = StrictField(
+    ] = StrictField(  # type: ignore[assignment]
         ...,
         title="Relationships",
         description="""Reference to the Links identifier object under the `links` endpoint that the provider has chosen as their 'default' OPTIMADE API database.
