@@ -12,30 +12,26 @@ used by the validator. The two main features being:
 
 """
 
-import time
-import sys
-import urllib.parse
 import dataclasses
+import json
+import sys
+import time
 import traceback as tb
-from typing import List, Optional, Dict, Any, Callable, Tuple
-
-try:
-    import simplejson as json
-except ImportError:
-    import json
+import urllib.parse
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import requests
 from pydantic import Field, ValidationError
 
 from optimade import __version__
-from optimade.models.optimade_json import Success
 from optimade.models import (
-    ResponseMeta,
     EntryResource,
     LinksResource,
     ReferenceResource,
+    ResponseMeta,
     StructureResource,
 )
+from optimade.models.optimade_json import Success
 
 # Default connection timeout allows for one default-sized TCP retransmission window
 # (see https://docs.python-requests.org/en/latest/user/advanced/#timeouts)
@@ -55,22 +51,22 @@ class InternalError(Exception):
     """
 
 
-def print_warning(string, **kwargs):
+def print_warning(string: str, **kwargs) -> None:
     """Print but angry."""
     print(f"\033[93m{string}\033[0m", **kwargs)
 
 
-def print_notify(string, **kwargs):
+def print_notify(string: str, **kwargs) -> None:
     """Print but louder."""
     print(f"\033[94m\033[1m{string}\033[0m", **kwargs)
 
 
-def print_failure(string, **kwargs):
+def print_failure(string: str, **kwargs) -> None:
     """Print but sad."""
     print(f"\033[91m\033[1m{string}\033[0m", **kwargs)
 
 
-def print_success(string, **kwargs):
+def print_success(string: str, **kwargs) -> None:
     """Print but happy."""
     print(f"\033[92m\033[1m{string}\033[0m", **kwargs)
 
@@ -117,9 +113,9 @@ class ValidatorResults:
         pretty_print = print if success_type == "optional" else print_success
 
         if self.verbosity > 0:
-            pretty_print(message)
+            pretty_print(message)  # type: ignore[operator]
         elif self.verbosity == 0:
-            pretty_print(".", end="", flush=True)
+            pretty_print(".", end="", flush=True)  # type: ignore[operator]
 
     def add_failure(
         self, summary: str, message: str, failure_type: Optional[str] = None
@@ -150,12 +146,12 @@ class ValidatorResults:
             self.optional_failure_count += 1
             self.optional_failure_messages.append((summary, message))
 
-        pprint_types = {
+        pprint_types: Dict[str, Tuple[Callable, Callable]] = {
             "internal": (print_notify, print_warning),
             "optional": (print, print),
         }
         pprint, warning_pprint = pprint_types.get(
-            failure_type, (print_failure, print_warning)
+            str(failure_type), (print_failure, print_warning)
         )
 
         symbol = "!" if failure_type == "internal" else "✖"
@@ -172,7 +168,7 @@ class Client:  # pragma: no cover
         self,
         base_url: str,
         max_retries: int = 5,
-        headers: Dict[str, str] = None,
+        headers: Optional[Dict[str, str]] = None,
         timeout: Optional[float] = DEFAULT_CONN_TIMEOUT,
         read_timeout: Optional[float] = DEFAULT_READ_TIMEOUT,
     ) -> None:
@@ -196,9 +192,9 @@ class Client:  # pragma: no cover
             read_timeout: Read timeout in seconds.
 
         """
-        self.base_url = base_url
-        self.last_request = None
-        self.response = None
+        self.base_url: str = base_url
+        self.last_request: Optional[str] = None
+        self.response: Optional[requests.Response] = None
         self.max_retries = max_retries
         self.headers = headers or {}
         if "User-Agent" not in self.headers:
@@ -271,7 +267,7 @@ class Client:  # pragma: no cover
             raise ResponseError(message)
 
 
-def test_case(test_fn: Callable[[Any], Tuple[Any, str]]):
+def test_case(test_fn: Callable[..., Tuple[Any, str]]):
     """Wrapper for test case functions, which pretty-prints any errors
     depending on verbosity level, collates the number and severity of
     test failures, returns the response and summary string to the caller.
@@ -294,7 +290,7 @@ def test_case(test_fn: Callable[[Any], Tuple[Any, str]]):
     def wrapper(
         validator,
         *args,
-        request: str = None,
+        request: Optional[str] = None,
         optional: bool = False,
         multistage: bool = False,
         **kwargs,
@@ -365,7 +361,7 @@ def test_case(test_fn: Callable[[Any], Tuple[Any, str]]):
                     success_type = "optional" if optional else None
                     validator.results.add_success(f"{request} - {msg}", success_type)
             else:
-                request = request.replace("\n", "")
+                request = request.replace("\n", "")  # type: ignore[union-attr]
                 message = msg.split("\n")
                 if validator.verbosity > 1:
                     # ValidationErrors from pydantic already include very detailed errors
@@ -373,8 +369,7 @@ def test_case(test_fn: Callable[[Any], Tuple[Any, str]]):
                     if not isinstance(result, ValidationError):
                         message += traceback.split("\n")
 
-                message = "\n".join(message)
-
+                failure_type = None
                 if isinstance(result, InternalError):
                     summary = (
                         f"{request} - {test_fn.__name__} - failed with internal error"
@@ -385,7 +380,7 @@ def test_case(test_fn: Callable[[Any], Tuple[Any, str]]):
                     failure_type = "optional" if optional else None
 
                 validator.results.add_failure(
-                    summary, message, failure_type=failure_type
+                    summary, "\n".join(message), failure_type=failure_type
                 )
 
                 # set failure result to None as this is expected by other functions
@@ -413,13 +408,13 @@ class ValidatorLinksResponse(Success):
 class ValidatorEntryResponseOne(Success):
     meta: ResponseMeta = Field(...)
     data: EntryResource = Field(...)
-    included: Optional[List[Dict[str, Any]]] = Field(None)
+    included: Optional[List[Dict[str, Any]]] = Field(None)  # type: ignore[assignment]
 
 
 class ValidatorEntryResponseMany(Success):
     meta: ResponseMeta = Field(...)
     data: List[EntryResource] = Field(...)
-    included: Optional[List[Dict[str, Any]]] = Field(None)
+    included: Optional[List[Dict[str, Any]]] = Field(None)  # type: ignore[assignment]
 
 
 class ValidatorReferenceResponseOne(ValidatorEntryResponseOne):
